@@ -38,6 +38,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/time.h>
+#include <sys/sysmacros.h>
 #include <sys/types.h>
 
 #define TABLE_SIZE		(17627)		/* Best if prime */
@@ -1356,7 +1357,7 @@ int main(int argc, char **argv)
 			if (ret == 0)
 				break;
 			if ((len = read(fan_fd, (void *)buffer, BUFFER_SIZE)) > 0) {
-				const struct fanotify_event_metadata *metadata;
+				struct fanotify_event_metadata *metadata;
 				metadata = (struct fanotify_event_metadata *)buffer;
 
 				while (FAN_EVENT_OK(metadata, len)) {
